flags

package
v1.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 21, 2017 License: MIT Imports: 5 Imported by: 6

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(name, env string, fallback bool, help string) *bool

Bool registers a flag and returns the pointer to the resulting boolean. The default value is passed as fallback and env sets the env variable that can override the default.

func Duration

func Duration(name, env string, fallback time.Duration, help string) *time.Duration

Duration registers a flag and returns the pointer to the resulting duration. The default value is passed as fallback and env sets the env variable that can override the default.

func String

func String(name, env, fallback, help string) *string

String registers a flag and returns the pointer to the resulting string. The default value is passed as fallback and env sets the env variable that can override the default.

Types

This section is empty.

Jump to