label

package
v1.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 21, 2017 License: MIT Imports: 2 Imported by: 4

Documentation

Index

Constants

const DefaultInstance = "default"

DefaultInstance is the name of the default reporter instance

Variables

This section is empty.

Functions

This section is empty.

Types

type Labels

type Labels struct {
	// contains filtered or unexported fields
}

Labels represent task labels for the specific complainer instance

func NewLabels

func NewLabels(complainer string, labels map[string]string, defaults bool) Labels

NewLabels creates labels for the specific complainer instance

func (Labels) InstanceLabel

func (l Labels) InstanceLabel(reporter, instance, name string) string

InstanceLabel returns label value for the specific reporter instance

func (Labels) Instances

func (l Labels) Instances(reporter string) []string

Instances returns configured instances of the specific reporter

func (Labels) String

func (l Labels) String() string

Jump to