Documentation
¶
Index ¶
Constants ¶
const DefaultInstance = "default"
DefaultInstance is the name of the default reporter instance
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Labels ¶
type Labels struct {
// contains filtered or unexported fields
}
Labels represent task labels for the specific complainer instance
func (Labels) InstanceLabel ¶
InstanceLabel returns label value for the specific reporter instance
Click to show internal directories.
Click to hide internal directories.